@@ -1228,6 +1228,71 @@ class PipelineEndpointLauncher:
         _ = requests.post(rest_endpoint, headers=auth_header, json=json_data)
 
 
+class BlobStorageManagerMoq:
+    def __init__(self, connection_string):
+        self.connection_string = connection_string
+    
+    def upload(self,blob_container,  file_path, overwrite_v = False):
+        #shutil.copy2(file_path, blob_container)
+        print("upload simulated")
+
+
+class AzureExperimentMoq:
+    def __init__(self):
+        self.runs = []
+
+    def get_runs(self):
+        return self.runs
+
+class AzureMLRunMoq:
+    def __init__(self, parent):
+        self.parent = parent
+
+        self.children = []
+        self.json_data = {}
+        self.tags = {}
+        self.metrics = {}
+
+    def get_children(self):
+        return self.children
+    
+    def get_details(self):
+        return self.json_data
+    
+    def get_tags(self):
+        return self.tags
+    
+    def get_metrics(self):
+        return self.metrics
+    
+    def log(self, title, value):
+        print("title :", title)
+        print("value :", value)
+
+    def log_image(self, title, plot):
+        print("tile:", title)
+        print("plot :", plot)
+        id = Helper.generate()
+        if self.temp_dir:
+            plot.savefig(os.path.join(self.temp_dir,"{0}_{1}.png".format(title, id)))
+    
+    def upload_file(self, name, path_or_stream):
+        print("name :", name)
+        print("path_or_stream :", path_or_stream)
+    
+    def set_temp_dir(self, temp_dir):
+        self.temp_dir = temp_dir
+
+class LoggerMoq(object):
+    def info(self, value, args={}):
+        print(value)
+
+    def warning(self, value, args={}):
+        print(value)
+    
+    def debug(self, value, args={}):
+        print(value)
+
 
 class LazyFileDataDumper:
     def __init__(self,featuresHandler,feature_index):
